/**
 * 全站路由配置
 *
 * 建议:
 * 1. 代码中路由统一使用name属性跳转(不使用path属性)
 */
import Vue from 'vue'
import Router from 'vue-router'
// import { clearLoginInfo } from '@/utils'

Vue.use(Router)

// 开发环境不使用懒加载, 因为懒加载页面太多的话会造成webpack热更新太慢, 所以只有生产环境使用懒加载
const _import = require('./import-' + process.env.NODE_ENV)

// 全局路由(无需嵌套上左右整体布局)
const globalRoutes = [
  { path: '/404', component: _import('common/404'), name: '404', meta: { title: '404未找到' } }
]

// 主入口路由(需嵌套上左右整体布局)
const mainRoutes = {
  path: '/',
  component: _import('main'),
  name: 'main',
  redirect: { name: 'home' },
  meta: { title: '主入口整体布局' },
  children: [
    // 通过meta对象设置路由展示方式
    // 1. isTab: 是否通过tab展示内容, true: 是, false: 否
    // 2. iframeUrl: 是否通过iframe嵌套展示内容, '以http[s]://开头': 是, '': 否
    // 提示: 如需要通过iframe嵌套展示内容, 但不通过tab打开, 请自行创建组件使用iframe处理!
    { path: '/login', component: _import('modules/account/login'), name: 'login', meta: { title: '登录' } },
    { path: '/register', component: _import('modules/account/register'), name: 'register', meta: { title: '注册' } },
    { path: '/home', component: _import('common/home'), name: 'home', meta: { title: '首页' } },
    {
      path: '/tools-analyze',
      component: _import('modules/tools/tools-analyze'),
      name: 'toolsAnalyze',
      meta: { title: '竞品透析' }
    },
    {
      path: '/tools-credit',
      component: _import('modules/tools/tools-credit'),
      name: 'toolsCredit',
      meta: { title: '淘宝极速验号，淘宝买家信誉在线查询，只需输入买家旺旺号，即可全方位稽查恶意退单、敲诈、打假师、差评师等。' }
    },
    {
      path: '/tools-online',
      component: _import('modules/tools/tools-online'),
      name: 'toolsOnline',
      meta: { title: '指数转化' }
    },
    // 个人中心
    {
      path: '/mine-paycheck',
      component: _import('modules/mine/mine-paycheck'),
      name: 'minePaycheck',
      meta: { title: '账户余额充值' }
    },
    {
      path: '/mine-wallet',
      component: _import('modules/mine/mine-wallet'),
      name: 'mineWallet',
      meta: { title: '我的钱包' }
    }
  ],
  beforeEnter (to, from, next) {
    // let token = Vue.cookie.get('token')
    // if (!token || !/\S/.test(token)) {
    //   clearLoginInfo()
    //   next({ name: 'login' })
    // }
    next()
  }
}

const router = new Router({
  mode: 'history',
  scrollBehavior (to, from, savedPosition) {
    if (to.hash) {
      return {
        selector: to.hash
      }
    }
    // keep-alive 返回缓存页面后记录浏览位置
    if (savedPosition && to.meta.keepAlive) {
      return savedPosition
    }
    // 异步滚动操作
    return new Promise((resolve) => {
      setTimeout(() => {
        resolve({ x: 0, y: 1 })
      }, 0)
    })
  },
  isAddDynamicMenuRoutes: false, // 是否已经添加动态(菜单)路由
  routes: globalRoutes.concat(mainRoutes)
})

router.beforeEach((to, from, next) => {
  next()
})

export default router
